<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>མ་ལག་ལྟ་སྲུང་ཆས།</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>མ་ལག་ལྟ་སྲུང་ཆས་ནི་མཁྲེགས་ཆས་ཐེག་ཁུར་དང་བྱ་རིམ་བཀོལ་སྤྱོད། མ་ལག་ཞབས་ཞུ་བཅས་ལ་དཔྱད་འཇལ་ལྟ་ཞིབ་དང་བཀོལ་སྤྱོད་དོ་དམ་བྱེད་པའི་མ་ལག་ཡོ་བྱད་ཅིག་རེད།</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>ཞིབ་ཕྲའི་གནས་ཚུལ་ཡིབ་པ།</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation>སྤྱིའི་བེད་སྤྱོད་བྱེད་ཚད།</translation>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation>སྒེར་གྱི་བེད་སྤྱོད་བྱེད་ཚད།</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>ཀློག་པ།</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>འབྲི་བ།</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>སྐར་ཆ་60</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>ཉིན་%1དང་ཆུ་ཚོད་%2སྐར་མ་%3</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>བེད་སྤྱད་ཚད།</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>མིག་སྔའི་ཟློས་ཕྱོད།</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>ཟློས་ཕྱོད།</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>འཇུག་ཤུར།</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>གཏན་ཚིགས་ཐག་གཅོད་ཆས།</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>རྟོག་བཟོ་ཅན།</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>L1གསོག་ཉར།</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>L1གསོག་ཉར།</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>L2 གསོག་ཉར།</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>L3གསོག་ཉར།</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>སྣོན་འཇུག་དོ་མཉམ།</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>ཡིག་ཆ་ཞིབ་འབྲིའི་རྟགས།</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>བྱ་རིམ་བརྒྱུད་རིམ།</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>སྐུད་རིམ་གྲངས་ཀ</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>རྩིས་འཁོར་ཨ་མའི་མིང་།</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>རིགས་གྲས།</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>པར་གཞི།</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>འཁོར་སྐྱོད་དུས་ཡུན།</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>སྐར་ཆ་60</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>འཚོལ་ཞིབ་བྱས་འབྲས་མེད།</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>ཞིབ་ཕྲའི་ཆ་འཕྲིན།</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>ཞིབ་ཕྲའི་ཆ་འཕྲིན།</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>འགོ་སློང་ཟིན།</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>ལྗིད་ཐེག་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>འགོ་སློང་མེད།</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>ཕམ་ཟིན།</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>འགོ་སློང་བཞིན་པ།</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>མཚམས་འཇོག་བཞིན་པ།</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>གནས་འཕྲོག</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>རྙེད་མེད་པ།</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>ནུས་མེད་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>error</source>
        <translation>ནོར་འཁྲུལ།</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>ཟླ་སྒྲིལ་ཟིན།</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>བཀག་ཟིན།</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>སྣོན་འཇུག་བྱས་ཟིན།</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>རང་འགུལ།</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>ལག་སྒུལ།</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>སྤྱོད་འགོ་ཚུགས་ཟིན།</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>static</source>
        <translation>ཞི་རྣམ།</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>འཕྲལ་རྣམ།</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>ཤུགས་སུ།</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>བཀོལ་སྤྱོད་སྐབས་སུ་སྤྱོད་རྒྱུ།</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>བཀག་ཟིན།</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>གྲུབ་ཟིན།</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>dead</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>སྔོན་དུ་འགོ་སློང་།</translation>
    </message>
    <message>
        <source>start</source>
        <translation>འགོ་སློང་བཞིན་པ།</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>start-post</translation>
    </message>
    <message>
        <source>running</source>
        <translation>བཀོལ་སྤྱོད་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>ཕྱིར་འཐེན་ཟིན།</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>ལྗིད་ཐེག་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>མཚམས་འཇོག་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>stop-post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>ཕམ་ཟིན།</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>རང་འགུལ་བསྐྱར་སློང་བྱེད་པ།</translation>
    </message>
</context>
<context>
    <name>DBusAlarmNotify</name>
    <message>
        <source>Warning</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your CPU usage is higher than %1%!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your memory usage is higher than %1%!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>སྤྱད་ཟིན།</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>སྤྱོད་རུང་བ།</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>མཉམ་སྤྱོད་ནང་གསོག</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>མྱུར་མགྱོགས་གསོག་ཉར།</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>གཞི་གྲངས་གསོག་ཉར།</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>བརྗེ་གསོག་ཁུལ།</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>བྱེད་སྒོ།</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>གནས་སྐབས་བེད་སྤྱོད་མེད་པའི་བར་ཁུལ་ཡིག་ཆ།</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>བཙོག་ཤོག</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>རྟེན་འཕྲོ་ཆེ་ཆུང་།</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>བརྗེ་སའི་བར་སྟོང་ཆེ་ཆུང་།</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>སྤྱོད་རུང་བའི་བརྗེ་སྟོང་།</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>གཞི་གྲངས་གྲུབ་ཚུལ་གསོག་ཉར།</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>བཟོ་རྟགས།</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>ཀློག་པའི་མྱུར་ཚད།</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>འབྲི་བའི་མྱུར་ཚད།</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>ཤོང་ཚད།</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>གཡབ་ཁུལ་ཀློག་གྲངས།</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>སྐར་ཆ་རེར་ཀློག་པའི་སྤྱོད་ཐེངས།</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>སྐར་ཆ་རེའི་གཡབ་ཁུལ་ཀློག་ཐེངས།</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>སྐར་ཆ་རེར་ཟླ་སྒྲིལ་ནས་ཀློག་པའི་སྤྱོད་ཐེངས།</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>གཡབ་ཁུལ་འབྲི་ཐེངས།</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>བྲིས་ཚར་བའི་ཐེངས་གྲངས།</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>ཟླ་སྒྲིལ་ནས་བྲིས་ཚར་བའི་ཐེངས་གྲངས།</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>སྐར་ཆ་རེར་འབྲི་ཐེངས།</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>སྐར་ཆ་རེའི་གཡབ་ཁུལ་འབྲི་ཐེངས།</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>སྐར་ཆ་རེའི་ཟླ་སྒྲིལ་ནས་འབྲི་ཐེངས།</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>ཆོག</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>མ་ལག</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>མྱུར་མཐེབ་འཆར་བ།</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>བརྒྱུད་རིམ་མཇུག་སྒྲིལ་་བྱས་ན་གཞི་གྲངས་བོར་བའི་ཉེན་ཁ་ཡོད། 
ཁྱེད་ཀྱིས་བདམས་པའི་བརྒྱུད་རིམ་མཇུག་སྒྲིལ་རྒྱུ་གཏན་འཁེལ་ལམ།</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>བརྒྱུད་རིམ་མཇུག་སྒྲིལ་བ།</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>བཙན་ཐབས་ཀྱིས་བརྒྱུད་རིམ་མཇུག་སྒྲིལ་་བྱས་ན་གཞི་གྲངས་བོར་བའི་ཉེན་ཁ་ཡོད། 
ཁྱེད་ཀྱིས་བདམས་པའི་བརྒྱུད་རིམ་མཇུག་སྒྲིལ་རྒྱུ་གཏན་འཁེལ་ལམ།</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>བཙན་ཐབས་ཀྱིས་ཉེར་སྤྱོད་མཇུག་སྒྲིལ་་བྱས་ན་གཞི་གྲངས་བོར་བའི་ཉེན་ཁ་ཡོད། 
ཁྱེད་ཀྱིས་བདམས་པའི་ཉེར་སྤྱོད་མཇུག་སྒྲིལ་རྒྱུ་གཏན་འཁེལ་ལམ།</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>འདོར་བ།</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>བཙན་ཐབས་ཀྱིས་མཇུག་སྒྲིལ་བ།</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>བརྒྱུད་རིམ་མཇུག་སྒྲིལ་བ།</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་འགོད།</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>ཤོང་ཚད་ཆེ་ཆུང་།</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>IPགནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>བུ་དྲའི་ཡིབ་ཨང་།</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>རླུང་འཕྲིན།</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>ཡིབ་ཨང་རིང་ཚད།</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>ཁོངས།</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>སྦྲེལ་མཐུད་རིགས།</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ཞབས་ཞུ་འཕྲུལ་ཆས་ཀྱི་ཨང་གྲངས་གཞན།</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>བརྡ་རྟགས་སྤུས་ཚད།</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>བརྡ་རྟགས་བྱང་ཚད།</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>སུར་སྒྲའི་རིམ་པ།</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>མྱུར་ཚད།</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>ལེན་ཁུག་གི་གྲངས།</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>ཁྱོན་དང་ལེན་བྱས་ཚད།</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>ནོར་བའི་ཁུག་མ་དང་ལེན།</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>གཡུག་པའི་ཁུག་མ་དང་ལེན།</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>དང་ལེན།FIFO</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>ཁག་བགོས་ནོར་བ།</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>ཁུག་མ་སྐྱེལ་སྤྲོད་ཀྱི་གྲངས་ཚད།</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>ཁྱོན་བསྐུར་བ།</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>ནོར་བའི་ཁུག་མ་བསྐུར་བ།</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>བསྐུར་བ།FIFO</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>རླབས་ཐེག་ཟད་གྲོན།</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>གཡུག་པའི་ཁུག་མ་བསྐུར་བ།</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>བཀའི་ཕྲེང་།</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>འགོ་སློང་དུས་ཚོད།</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>མིང་།</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>ཁྱེད་ཀྱིས་མཇུག་སྒྲིལ་འདོད་པའི་ཉེར་སྤྱོད་བྱ་རིམ་མནན་རྒྱུ།</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>ནང་གསོག</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>དང་ལེན།</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>ཐག་གཅོད་ཆས།</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>སྡུད་སྡེར་ཀློག་ལེན།</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>སྡུད་སྡེར་འབྲི་བ།</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>ནང་གསོག</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>བརྗེ་སྤྲོད་བར་སྣང་།</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>སྤྱོད་འགོ་ཚུགས་མེད།</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>ཕབ་ལེན།</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>སྐྱེལ་འཇོག</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>དྲ་བ།</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>བསྡུ་ལེན་བྱས་པའི་བསྡོམས་གྲངས།</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>བསྐུར་བའི་བསྡོམས་གྲངས།</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>བསྐུར་བ།</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>སྡུད་སྡེར།</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>སྣོན་འཇུག</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>ཧ་ཅང་མཐོ།</translation>
    </message>
    <message>
        <source>High</source>
        <translation>མཐོ།</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>སྤྱིར་བཏང་།</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>དམའ།</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>ཧ་ཅང་དམའ།</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>རང་སྒྲུབ།</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>ནུས་མེད།</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>བརྒྱུད་རིམ་ཨང་རྟགས། : %1, Error: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>བརྒྱུད་རིམ་གྱི་སྔོན་རིམ་བསྒྱུར་མི་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>ཉེར་སྤྱོད་བྱ་རིམ།</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>ངའི་བརྒྱུད་རིམ།</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>བརྒྱུད་རིམ་ཚང་མ།</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>བརྒྱུད་རིམ་མཚམས་འཇོག་བྱེད་མི་ཐུབ།</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>བརྒྱུད་རིམ་སླར་གསོ་བྱེད་མི་ཐུབ།</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>བཙན་ཐབས་ཀྱིས་བརྒྱུད་རིམ་མཇུག་སྒྲིལ་མི་ཐུབ།</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>མི་ཤེས་པའི་ནོར་འཁྲུལ།</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>བརྒྱུད་རིམ་དུ་བརྡ་རྟགས་བསྐུར་མི་ཐུབ།</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>བརྒྱུད་རིམ་མཇུག་སྒྲིལ་བྱེད་མི་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>（ཉེར་སྤྱོད་བྱ་རིམ་%1དང་མ་ལག་བརྒྱུད་རིམ་%2བཀོལ་སྤྱོད་བྱེད་བཞིན་ཡོད།）</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>ཡ་ལན་མེད།</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>སྐབས་འཇོག</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>འདེགས་སྡེར།</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>བཀའ་ཡོད་སའི་ས་གནས་ལྟ་བཤེར་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>ངོ་བོ།</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>བརྒྱུད་རིམ་མཇུག་སྒྲིལ་བ།</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>བརྒྱུད་རིམ་མུ་མཐུད་སྤྱོད་པ།</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>བཙན་ཐབས་ཀྱིས་བརྒྱུད་རིམ་མཇུག་སྒྲིལ་བ།</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>སྔོན་རིམ་བསྒྱུར་བ།</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>བརྒྱུད་རིམ་མཚམས་འཇོག་པ།</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>རང་སྒྲུབ་སྔོན་རིམ།</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>འདོར་བ།</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>བསྒྱུར་བ།</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>མིང་།</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>ཐག་གཅོད་ཆས།</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>ནང་གསོག</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>སྡུད་སྡེར་འབྲི་བ།</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>སྡུད་སྡེར་ཀློག་ལེན།</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>ཕབ་ལེན།</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>སྐྱེལ་འཇོག</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>བརྒྱུད་རིམ་ཨང་རྟགས།</translation>
    </message>
    <message>
        <source>User</source>
        <translation>སྤྱོད་མཁན།</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>སྔོན་རིམ།</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>མཉམ་སྤྱོད་ནང་གསོག</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>རྟོག་བཟོའི་ནང་གསོག</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>རྒྱབ་སྐྱོར་མེད་པ།</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>རྒྱུད་ཁོངས་འགོག་སྲུང་།</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>གྲངས་ཚད་གཤམ་གྱི་ཁྱབ་ཁོངས་ལས་མཐོ་བ་ཡོད་སྐབས་རང་འགུལ་ངང་ཉེན་བརྡ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>CPU (%)ཟིན་པ།</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>ནང་གསོག་ (%)ཟིན་པ།</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>ཉེན་བརྡ་གཏོང་བའི་བར་ཐག(སྐར་མ)</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>ཆ་འཕྲིན་བརྡ་ཐོ།</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>ཞབས་ཞུའི་འགོ་སློང་བྱེད་ཐབས་སྒྲིག་འགོད་བྱེད་མི་ཐུབ།</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>ནོར་འཁྲུལ། ཡན་ལག་བརྒྱུད་རིམ་ཐོར་བའི་རྐྱེན་གྱིས། ཞབས་ཞུའི་འགོ་སློང་བྱེད་ཐབས་སྒྲིག་འགོད་བྱེད་མི་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>ཞབས་ཞུ་དངོས་དཔེའི་མིང་།</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>ཆོག</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>འདོར་བ།</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>གསར་འདོན།</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>འགོ་སློང་།</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>མཚམས་འཇོག</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>བསྐྱར་སློང་།</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>རང་འགུལ།</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>ལག་སྒུལ།</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>འགོ་སློང་ཐབས་སྒྲིག་འགོད།</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>མིང་།</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>ནང་གསོག་སྣོན་འཇུག</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="vanished">བྱེད་སྒོ།</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>བཀོལ་སྤྱོད་རྣམ་པ།</translation>
    </message>
    <message>
        <source>State</source>
        <translation type="vanished">རྣམ་པ།</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>ཞིབ་བརྗོད།</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>བརྒྱུད་རིམ་ཨང་རྟགས།</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>འགོ་སློང་ཐབས།</translation>
    </message>
    <message>
        <source>Start State</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start Tactic</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>（གྲངས་ཚད་བཅོས་ཆོག）</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>གྲངས་ཚད་ཀྱི་ཁྱབ་ཁོངས། %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>བཙན་ཐབས་ཀྱིས་ཉེར་སྤྱོད་བྱ་རིམ་མཇུག་སྒྲིལ་བ།</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>ལྷོད་པོ།</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>དམ་པོ།</translation>
    </message>
    <message>
        <source>View</source>
        <translation>མཐོང་རིས།</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>འཚོལ་ཞིབ།</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>བྱ་རིམ་བརྒྱུད་རིམ།</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>མ་ལག་ཞབས་ཞུ།</translation>
    </message>
    <message>
        <source>Users</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>User.Account.Type</name>
    <message>
        <source>Administrator</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Standard User</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>User.Account.Operation</name>
    <message>
        <source>Edit account information</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>